message_update_telegram_tracked = {
    "update_id": 633291228,
    "message": {
        "message_id": 119,
        "from": {
            "id": 714862471,
            "is_bot": False,
            "first_name": "Chris",
            "username": "candyflipline",
            "language_code": "en",
            "is_premium": True,
        },
        "chat": {
            "id": 714862471,
            "first_name": "Chris",
            "username": "candyflipline",
            "type": "private",
        },
        "date": 1709659308,
        "text": "/start",
        "entities": [{"offset": 0, "length": 6, "type": "bot_command"}],
    },
}

message_update_telegram_not_tracked = {
    "update_id": 633291229,
    "message": {
        "message_id": 121,
        "from": {
            "id": 714862471,
            "is_bot": False,
            "first_name": "Chris",
            "username": "candyflipline",
            "language_code": "en",
            "is_premium": True,
        },
        "chat": {
            "id": 714862471,
            "first_name": "Chris",
            "username": "candyflipline",
            "type": "private",
        },
        "date": 1709660718,
        "text": "I'm not even tracked fool",
    },
}

edited_message_update_tracked = {
    "update_id": 633291230,
    "edited_message": {
        "message_id": 121,
        "from": {
            "id": 714862471,
            "is_bot": False,
            "first_name": "Chris",
            "username": "candyflipline",
            "language_code": "en",
            "is_premium": True,
        },
        "chat": {
            "id": 714862471,
            "first_name": "Chris",
            "username": "candyflipline",
            "type": "private",
        },
        "date": 1709660718,
        "edit_date": 1709661075,
        "text": "/start",
    },
}

edited_message_update_not_tracked = {
    "update_id": 633291230,
    "edited_message": {
        "message_id": 121,
        "from": {
            "id": 714862471,
            "is_bot": False,
            "first_name": "Chris",
            "username": "candyflipline",
            "language_code": "en",
            "is_premium": True,
        },
        "chat": {
            "id": 714862471,
            "first_name": "Chris",
            "username": "candyflipline",
            "type": "private",
        },
        "date": 1709660718,
        "edit_date": 1709661075,
        "text": "Not tracked",
    },
}

inline_query_update_telegram = {
    "update_id": 633291231,
    "inline_query": {
        "id": "3070310935021018023",
        "from": {
            "id": 714862471,
            "is_bot": False,
            "first_name": "Chris",
            "username": "candyflipline",
            "language_code": "en",
            "is_premium": True,
        },
        "chat_type": "sender",
        "query": "",
        "offset": "",
    },
}

chosen_inline_result_update_telegram = {
    "update_id": 633291233,
    "chosen_inline_result": {
        "from": {
            "id": 714862471,
            "is_bot": False,
            "first_name": "Chris",
            "username": "candyflipline",
            "language_code": "en",
            "is_premium": True,
        },
        "inline_message_id": "BQAAAKA4CQCH75sq3s_7z2oZyT8",
        "query": "",
        "result_id": "ITEM-2ac2dbd3-8467-40c0-8500-d3b50e75972b",
    },
}
